@@ -12,9 +12,9 @@ import requests
 
 from .mongo_tools import clean_json
 from .data_utils import to_dicts
-from .parsing import parse_float, parse_int
+from .parsing import parse_float, parse_int, lower_string
 
-__version__ = "0.1.21"
+__version__ = "0.1.22"
 
 
 def logged_user(logger=logger):
